from django.contrib.auth import get_user_model
from django.dispatch import receiver
from django.db.models.signals import post_save

from subscriptions_api.models import activate_default_user_subscription


@receiver(post_save, sender=get_user_model(), dispatch_uid='assign_default_subscription')
def create_default_subscription(sender, instance, created, **kwargs):
    if created:
        activate_default_user_subscription(instance)



# Generated by Django 4.1 on 2022-11-26 10:41

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('subscriptions_api', '0008_auto_20210128_0337'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='subscriptionplan',
            options={'ordering': ('sequence',), 'permissions': (('subscriptions', 'Can interact with subscription details'),)},
        ),
        migrations.AddField(
            model_name='subscriptionplan',
            name='sequence',
            field=models.IntegerField(default=0, help_text='order by sequence '),
        ),
        migrations.AddField(
            model_name='usersubscription',
            name='quantity',
            field=models.IntegerField(default=1, help_text='Subscription Quantity'),
        ),
        migrations.AlterField(
            model_name='planlist',
            name='id',
            field=models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID'),
        ),
        migrations.AlterField(
            model_name='planlistdetail',
            name='id',
            field=models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID'),
        ),
        migrations.AlterField(
            model_name='plantag',
            name='id',
            field=models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID'),
        ),
    ]



# Generated by Django 3.0.5 on 2020-10-17 06:51

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('subscriptions_api', '0004_auto_20200908_1400'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='planlist',
            options={'ordering': ('title',)},
        ),
        migrations.AlterField(
            model_name='subscriptionplan',
            name='features',
            field=models.TextField(blank=True, help_text='list of json allowed features for this plan', null=True),
        ),
    ]



# Generated by Django 3.0.5 on 2020-10-17 18:52

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('subscriptions_api', '0005_auto_20201017_0651'),
    ]

    operations = [
        migrations.AddField(
            model_name='usersubscription',
            name='reference',
            field=models.CharField(blank=True, help_text='External System Reference', max_length=100, null=True),
        ),
    ]



# Generated by Django 3.0.5 on 2020-11-17 12:09

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('subscriptions_api', '0006_usersubscription_reference'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='planlist',
            name='features_ref',
        ),
        migrations.AddField(
            model_name='planlist',
            name='features',
            field=models.TextField(blank=True, help_text='Json dict for allowed features to display for the plan list', null=True),
        ),
    ]



# Generated by Django 4.1 on 2022-11-27 01:09

import django.core.validators
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('subscriptions_api', '0009_alter_subscriptionplan_options_and_more'),
    ]

    operations = [
        migrations.AddField(
            model_name='plancost',
            name='min_subscription_quantity',
            field=models.IntegerField(default=1, help_text='optional minimum subscription qty  user needs to subscribe to use this cost for usage and tiered base subscription', validators=[django.core.validators.MinValueValidator(1)]),
        ),
    ]
